%define anolis_release 1
%global  _hardened_build     1
%global  nginx_user          nginx

# Disable strict symbol checks in the link editor.
%undefine _strict_symbol_defs_build

%bcond_with geoip

%bcond_with gperftools

%bcond_without aio

%bcond_without mailcap_mimetypes

# Cf. https://www.nginx.com/blog/creating-installable-packages-dynamic-modules/
%global nginx_abiversion %{version}

%global nginx_moduledir %{_libdir}/nginx/modules
%global nginx_moduleconfdir %{_datadir}/nginx/modules
%global nginx_srcdir %{_usrsrc}/%{name}-%{version}-%{release}

# Do not generate provides/requires from nginx sources
%global __provides_exclude_from ^%{nginx_srcdir}/.*$
%global __requires_exclude_from ^%{nginx_srcdir}/.*$


Name:              nginx
Epoch:             1
Version:           1.26.2
Release:           %{anolis_release}%{?dist}

Summary:           A high performance web server and reverse proxy server
# BSD License (two clause)
License:           BSD
URL:               https://nginx.org

Source0:           https://nginx.org/download/nginx-%{version}.tar.gz
Source10:          nginx.service
Source11:          nginx.logrotate
Source12:          nginx.conf
Source13:          nginx-upgrade
Source14:          nginx-upgrade.8
Source15:          macros.nginxmods.in
Source16:          nginxmods.attr
Source102:         nginx-logo.png
Source103:         404.html
Source104:         50x.html
Source200:         README.dynamic
Source210:         UPGRADE-NOTES-1.6-to-1.10


BuildRequires:     make gcc
%if 0%{with gperftools}
BuildRequires:     gperftools-devel
%endif
BuildRequires:     zlib-devel pcre2-devel openssl-devel

Requires:          pcre2
Provides:          webserver
Recommends:        logrotate
Requires:          system-logos-httpd
Requires:          %{name}-core = %{epoch}:%{version}-%{release}
Requires:          nginx-filesystem = %{epoch}:%{version}-%{release}

BuildRequires:     systemd
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd
# For external nginx modules
Provides:          nginx(abi) = %{nginx_abiversion}

%description
Nginx is a popular open-source web server and reverse proxy server that was
created by Igor Sysoev in 2004. It has gained a reputation for being a high-
performance, highly scalable software that can handle large amounts of traffic
while using minimal resources.

One of the main reasons for Nginx's popularity is its ability to handle multiple
concurrent connections very efficiently. It can serve static content with ease
and also handle dynamic content, making it a suitable choice for a wide range of
websites and applications.

Nginx can also act as a reverse proxy server, which means it can handle requests
on behalf of other web servers. This feature is particularly useful in load-
balancing scenarios where multiple web servers are used to handle high-traffic
websites.

Furthermore, Nginx can be used as a load balancer to distribute requests across
multiple servers to improve performance and reliability. It can also terminate
SSL/TLS connections, which offloads the encryption/decryption process from the
web server and improves performance.

Another feature of Nginx is its ability to cache frequently accessed content,
which reduces the load on web servers and improves performance. It can also
compress HTTP responses to reduce the amount of data sent over the network,
which also improves performance.

Nginx is modular and can be extended with additional modules to add new features
and functionality. There are many third-party modules available that can be
added to Nginx to customize its behavior for specific use cases.

In summary, Nginx is a robust and reliable web server and reverse proxy server
that can handle high traffic websites and applications. Its efficiency, speed,
and scalability make it a popular choice among developers and system
administrators.

%package all-modules
Summary:           A meta package that installs all available Nginx modules
BuildArch:         noarch

%if %{with geoip}
Requires:          nginx-mod-http-geoip = %{epoch}:%{version}-%{release}
%endif
Requires:          nginx-mod-http-image-filter = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-http-perl = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-http-xslt-filter = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-mail = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-stream = %{epoch}:%{version}-%{release}

%description all-modules
Meta package that installs all available nginx modules.

%package core
Summary: nginx minimal core
%if 0%{with mailcap_mimetypes}
Requires:          nginx-mimetypes
%endif
Requires:          openssl-libs
Requires(pre):     nginx-filesystem

%description core
nginx minimal core

%package filesystem
Summary:           The basic directory layout for the Nginx server
BuildArch:         noarch
Requires(pre):     shadow-utils

%description filesystem
The nginx-filesystem package contains the basic directory layout
for the Nginx server including the correct permissions for the
directories.

%if %{with geoip}
%package mod-http-geoip
Summary:           Nginx HTTP geoip module
BuildRequires:     GeoIP-devel
Requires:          nginx(abi) = %{nginx_abiversion}
Requires:          GeoIP

%description mod-http-geoip
nginx mod-http-geoip is a module that enables Nginx to perform geolocation
lookups for IP addresses. It integrates with the GeoIP database, which
contains information about the location of IP addresses, including country,
region, city, and latitude/longitude coordinates.

When a request is received by Nginx, the mod-http-geoip module extracts the
IP address of the client and performs a lookup in the GeoIP database to
determine the client's location. This information can then be used to customize
the response to the request, for example by redirecting the client to a localized
version of a website, or by serving different content based on the client's
country of origin.

To use nginx mod-http-geoip, you need to download and install the GeoIP library
and database, and then compile and configure the module in Nginx. Once it's set
up, you can use nginx mod-http-geoip to enhance the functionality of your web
server, for example by targeting specific audiences with localized content or by
blocking traffic from certain countries.

Overall, nginx mod-http-geoip is a powerful tool for anyone who needs to
customize their web server based on the geographic location of their clients.
%endif

%package mod-http-image-filter
Summary:           Nginx HTTP image filter module
BuildRequires:     gd-devel
Requires:          nginx(abi) = %{nginx_abiversion}
Requires:          gd

%description mod-http-image-filter
nginx mod-http-image-filter is a module that allows Nginx to resize, crop, rotate,
and adjust the quality of images on the fly. With this module enabled, Nginx can
act as a powerful image processing server, serving images in a variety of formats
and sizes with minimal overhead.

The mod-http-image-filter module integrates with the GD, ImageMagick, and OpenCV
libraries to perform image processing tasks. This means you can choose the library
that works best for your needs, whether you need to optimize for speed, quality,
or compatibility with specific image formats.

Once the module is enabled and configured, Nginx can automatically process incoming
image requests according to the parameters specified in the URL. For example, you
can request an image in a specific size or format, or apply a crop or rotation to
an image.

In addition to resizing and manipulating individual images, mod-http-image-filter
can also be used to generate image thumbnails and create image galleries. This
makes it a useful tool for building websites that rely heavily on images, such as
photography or e-commerce sites.

Overall, nginx mod-http-image-filter is a flexible and powerful module that can
significantly enhance the image processing capabilities of your web server. Whether
you need to resize images on the fly or generate complex image galleries, this
module can help you achieve your goals with ease.

%package mod-http-perl
Summary:           Nginx HTTP perl module
BuildRequires:     perl-devel
BuildRequires:     perl-generators
BuildRequires:     perl(ExtUtils::Embed)
Requires:          nginx(abi) = %{nginx_abiversion}
Requires:          perl(constant)

%description mod-http-perl
nginx mod-http-perl is a module that allows you to extend Nginx's
functionality using the Perl programming language. With this module
enabled, you can write Perl scripts that can be executed directly within
the Nginx server, giving you greater flexibility and control over how your
server handles requests.

The mod-http-perl module provides a range of hooks that allow your Perl
scripts to interact with Nginx at various stages of the request handling
process. For example, you can use the module to manipulate request headers,
modify response status codes, or even dynamically generate content on the
fly.

One of the major benefits of using Perl with Nginx is the ability to perform
complex text processing tasks. Perl is known for its powerful regular
expression capabilities, and you can use these features to perform advanced
string matching and replacement operations within your Nginx server.

Another key advantage of using mod-http-perl is the ability to reuse existing
Perl code within your Nginx server. If you have existing Perl scripts or
modules that you use for other projects, you can easily incorporate them
into your Nginx server to extend its capabilities.

Overall, nginx mod-http-perl is a powerful tool for extending the
functionality of your Nginx server. Whether you need to perform complex text
processing tasks or interact with external APIs and databases, this module
can help you achieve your goals with ease.

%package mod-http-xslt-filter
Summary:           Nginx XSLT module
BuildRequires:     libxslt-devel
Requires:          nginx(abi) = %{nginx_abiversion}

%description mod-http-xslt-filter
Nginx mod-http-xslt-filter is a module that allows you to transform XML
documents using XSLT (Extensible Stylesheet Language Transformations)
within Nginx. With this module enabled, you can use XSLT stylesheets
to transform XML documents into different formats, such as HTML, XHTML,
or even plain text.

The mod-http-xslt-filter module provides a range of configuration options
that allow you to specify the location of your XSLT stylesheets, as well
as the input and output formats for your XML documents. Additionally, you
can use the module to perform various XSLT transformations, such as copying,
selecting, and modifying nodes within your XML documents.

One of the major benefits of using mod-http-xslt-filter is the ability to
perform XML transformations directly within Nginx, without the need for
additional middleware or servers. This can help to improve your server's
performance and reduce latency, as well as allowing you to simplify your
architecture by consolidating your XML transformation logic in one place.

Another key advantage of using mod-http-xslt-filter is the flexibility it
provides in terms of XSLT stylesheet management. You can easily swap out or
update your stylesheets as needed, without having to modify your underlying
application code. This can help to streamline your development and deployment
processes, and allow you to quickly respond to changing business requirements.

Overall, nginx mod-http-xslt-filter is a powerful tool for transforming XML
documents within your Nginx server. Whether you need to convert XML to HTML
for display in a web browser, or transform complex XML data into simpler
formats for consumption by other systems, this module can help you achieve
your goals with ease.

%package mod-mail
Summary:           Nginx mail modules
Requires:          nginx(abi) = %{nginx_abiversion}

%description mod-mail
mod-mail is a module that enables email proxy and filtering capabilities within
Nginx. It allows Nginx to act as a mail server, handling incoming and outgoing email
traffic, as well as providing filtering and routing rules.

With the mod-mail module, Nginx can proxy incoming email traffic to other mail servers,
such as Microsoft Exchange, IMAP or SMTP servers, and SMTP relays. It can also act as
a front-end mail gateway, filtering and scanning incoming emails for spam, viruses,
and other threats before forwarding them to the appropriate email server.

One of the key benefits of using the mod-mail module is the ability to configure email
filtering rules based on various criteria, such as sender, recipient, subject,
attachment type, and more. This allows administrators to enforce policies and
restrictions on incoming and outgoing email traffic, helping to protect their
organization's network and data.

Additionally, mod-mail allows for flexible routing of email traffic based on various
parameters, such as domain name, sender or recipient address, and more. This can help
organizations achieve better control over their email traffic and ensure that messages
are delivered to the appropriate mail server.

Overall, Nginx mod-mail is a powerful module that can help organizations improve their
email infrastructure and security by providing filtering, routing, and proxy
capabilities within Nginx.

%package mod-stream
Summary:           Nginx stream modules
Requires:          nginx(abi) = %{nginx_abiversion}

%description mod-stream
mod-stream is a module that provides stream processing capabilities within
Nginx. It allows Nginx to act as a TCP/UDP proxy, load balancer, and traffic
shaper, providing enhanced performance, scalability, and flexibility for network
traffic handling.

With the mod-stream module, Nginx can handle various types of network traffic,
including HTTP, HTTPS, SMTP, DNS, and more. It can proxy incoming traffic to
multiple backend servers, balancing the load across them to ensure optimal
performance and availability.

In addition to load balancing, mod-stream also provides traffic shaping
capabilities, allowing administrators to prioritize and control network traffic
based on various criteria, such as source/destination IP addresses, ports,
protocols, and more. This helps organizations to optimize their network
performance, minimize latency and packet loss, and ensure that critical
applications and services receive the necessary bandwidth.

Another key feature of mod-stream is its support for SSL/TLS encryption and
decryption, enabling Nginx to act as a secure gateway for TCP/UDP traffic. This
helps to protect sensitive data and ensure secure communication between clients
and backend servers.

Overall, Nginx mod-stream is a powerful module that can provide enhanced network
traffic handling capabilities within Nginx, improving performance, scalability,
and security for organizations.

%package mod-devel
Summary:           Nginx module development files
Requires:          nginx = %{epoch}:%{version}-%{release}
Requires:          make
Requires:          gcc
Requires:          gd-devel
%if 0%{with gperftools}
Requires:          gperftools-devel
%endif
%if %{with geoip}
Requires:          GeoIP-devel
%endif
Requires:          libxslt-devel
Requires:          openssl-devel
Requires:          pcre2-devel
Requires:          perl-devel
Requires:          perl(ExtUtils::Embed)
Requires:          zlib-devel

%description mod-devel
%{summary}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
cp %{SOURCE200} %{SOURCE210} %{SOURCE10} %{SOURCE12} .

# Prepare sources for installation
cp -a ../%{name}-%{version} ../%{name}-%{version}-%{release}-src
mv ../%{name}-%{version}-%{release}-src .


%build
export DESTDIR=%{buildroot}
# So the perl module finds its symbols:
nginx_ldopts="%{build_ldflags} -Wl,-E"
if ! ./configure \
    --with-debug \
    --with-compat \
    --user=%{nginx_user} \
    --group=%{nginx_user} \
    --with-http_dav_module \
    --with-http_flv_module \
    --pid-path=/run/nginx.pid \
    --prefix=%{_datadir}/nginx \
    --with-http_addition_module \
    --sbin-path=%{_sbindir}/nginx \
    --with-http_degradation_module \
    --with-http_auth_request_module \
    --modules-path=%{nginx_moduledir} \
    --lock-path=/run/lock/subsys/nginx \
    --conf-path=%{_sysconfdir}/nginx/nginx.conf \
    --http-log-path=%{_localstatedir}/log/nginx/access.log \
    --error-log-path=%{_localstatedir}/log/nginx/error.log \
    --http-scgi-temp-path=%{_localstatedir}/lib/nginx/tmp/scgi \
    --http-proxy-temp-path=%{_localstatedir}/lib/nginx/tmp/proxy \
    --http-uwsgi-temp-path=%{_localstatedir}/lib/nginx/tmp/uwsgi \
    --http-fastcgi-temp-path=%{_localstatedir}/lib/nginx/tmp/fastcgi \
    --http-client-body-temp-path=%{_localstatedir}/lib/nginx/tmp/client_body \
%if 0%{with aio}
    --with-file-aio \
%endif
%if 0%{with gperftools}
    --with-google_perftools_module \
%endif
%if %{with geoip}
    --with-http_geoip_module=dynamic \
%endif
    --with-pcre \
    --with-threads \
    --with-pcre-jit \
    --with-mail=dynamic \
    --with-stream=dynamic \
    --with-http_v2_module \
    --with-http_ssl_module \
    --with-http_mp4_module \
    --with-mail_ssl_module \
    --with-http_sub_module \
    --with-stream_ssl_module \
    --with-http_slice_module \
    --with-http_gunzip_module \
    --with-http_realip_module \
    --with-http_stub_status_module \
    --with-http_secure_link_module \
    --with-http_gzip_static_module \
    --with-http_perl_module=dynamic \
    --with-http_random_index_module \
    --with-http_xslt_module=dynamic \
    --with-stream_ssl_preread_module \
    --with-http_image_filter_module=dynamic \
    --with-cc-opt="%{build_cflags} $(pcre2-config --cflags)" \
    --with-ld-opt="$nginx_ldopts"; then
  : configure failed
  cat objs/autoconf.err
  exit 1
fi

%make_build


%install
%make_install INSTALLDIRS=vendor

find %{buildroot} -type f -name .packlist -exec rm -f '{}' \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f '{}' \;
find %{buildroot} -type f -empty -exec rm -f '{}' \;
find %{buildroot} -type f -iname '*.so' -exec chmod 0755 '{}' \;

install -m 0644 -p -D ./nginx.service \
    %{buildroot}%{_unitdir}/nginx.service
install -m 0644 -p -D %{SOURCE11} \
    %{buildroot}%{_sysconfdir}/logrotate.d/nginx

install -m 0755 -p -d %{buildroot}%{_sysconfdir}/systemd/system/nginx.service.d
install -m 0755 -p -d %{buildroot}%{_unitdir}/nginx.service.d

install -m 0755 -p -d %{buildroot}%{_sysconfdir}/nginx/conf.d
install -m 0755 -p -d %{buildroot}%{_sysconfdir}/nginx/default.d

install -m 0700 -p -d %{buildroot}%{_localstatedir}/lib/nginx
install -m 0700 -p -d %{buildroot}%{_localstatedir}/lib/nginx/tmp
install -m 0700 -p -d %{buildroot}%{_localstatedir}/log/nginx

install -m 0755 -p -d %{buildroot}%{_datadir}/nginx/html
install -m 0755 -p -d %{buildroot}%{nginx_moduleconfdir}
install -m 0755 -p -d %{buildroot}%{nginx_moduledir}

install -m 0644 -p ./nginx.conf \
    %{buildroot}%{_sysconfdir}/nginx

install -m 0644 -p %{SOURCE102} \
    %{buildroot}%{_datadir}/nginx/html
ln -s nginx-logo.png %{buildroot}%{_datadir}/nginx/html/poweredby.png
mkdir -p %{buildroot}%{_datadir}/nginx/html/icons

# Symlink for the powered-by-$DISTRO image:
ln -s ../../../pixmaps/poweredby.png \
      %{buildroot}%{_datadir}/nginx/html/icons/poweredby.png

ln -s ../../pixmaps/system-noindex-logo.png \
      %{buildroot}%{_datadir}/nginx/html/system_noindex_logo.png

install -p -m 0644 %{SOURCE103} %{SOURCE104} \
    %{buildroot}%{_datadir}/nginx/html

%if 0%{with mailcap_mimetypes}
rm -f %{buildroot}%{_sysconfdir}/nginx/mime.types
%endif

install -m 0644 -p -D %{_builddir}/nginx-%{version}/objs/nginx.8 \
    %{buildroot}%{_mandir}/man8/nginx.8

install -m 0755 -p -D %{SOURCE13} %{buildroot}%{_bindir}/nginx-upgrade
install -m 0644 -p -D %{SOURCE14} %{buildroot}%{_mandir}/man8/nginx-upgrade.8

for i in ftdetect ftplugin indent syntax; do
    install -m644 -p -D contrib/vim/${i}/nginx.vim \
        %{buildroot}%{_datadir}/vim/vimfiles/${i}/nginx.vim
done

%if %{with geoip}
echo 'load_module "%{nginx_moduledir}/ngx_http_geoip_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-geoip.conf
%endif
echo 'load_module "%{nginx_moduledir}/ngx_http_image_filter_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-image-filter.conf
echo 'load_module "%{nginx_moduledir}/ngx_http_perl_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-perl.conf
echo 'load_module "%{nginx_moduledir}/ngx_http_xslt_filter_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-xslt-filter.conf
echo 'load_module "%{nginx_moduledir}/ngx_mail_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-mail.conf
echo 'load_module "%{nginx_moduledir}/ngx_stream_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-stream.conf

# Install files for supporting nginx module builds
## Install source files
mkdir -p %{buildroot}%{_usrsrc}
mv %{name}-%{version}-%{release}-src %{buildroot}%{nginx_srcdir}
## Install rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
sed -e "s|@@NGINX_ABIVERSION@@|%{nginx_abiversion}|g" \
    -e "s|@@NGINX_MODDIR@@|%{nginx_moduledir}|g" \
    -e "s|@@NGINX_MODCONFDIR@@|%{nginx_moduleconfdir}|g" \
    -e "s|@@NGINX_SRCDIR@@|%{nginx_srcdir}|g" \
    %{SOURCE15} > %{buildroot}%{_rpmmacrodir}/macros.nginxmods
## Install dependency generator
install -Dpm0644 %{SOURCE16} %{buildroot}%{_fileattrsdir}/nginxmods.attr

%generate_compatibility_deps


%pre filesystem
getent group %{nginx_user} > /dev/null || groupadd -r %{nginx_user}
getent passwd %{nginx_user} > /dev/null || \
    useradd -r -d %{_localstatedir}/lib/nginx -g %{nginx_user} \
    -s /sbin/nologin -c "Nginx web server" %{nginx_user}
exit 0

%post
%systemd_post nginx.service

%if %{with geoip}
%post mod-http-geoip
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%post mod-http-image-filter
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-http-perl
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-http-xslt-filter
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-mail
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-stream
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%preun
%systemd_preun nginx.service

%postun
%systemd_postun nginx.service
if [ $1 -ge 1 ]; then
    /usr/bin/nginx-upgrade >/dev/null 2>&1 || :
fi

%files
%dir %{abidir}
%{_datadir}/nginx/html/*
%{_bindir}/nginx-upgrade
%{_mandir}/man8/nginx.8*
%{_unitdir}/nginx.service
%{abidir}/nginx-option.list
%{abidir}/nginx.dump
%{_mandir}/man3/nginx.3pm*
%{_mandir}/man8/nginx-upgrade.8*
%{_datadir}/vim/vimfiles/syntax/nginx.vim
%{_datadir}/vim/vimfiles/indent/nginx.vim
%{_datadir}/vim/vimfiles/ftdetect/nginx.vim
%{_datadir}/vim/vimfiles/ftplugin/nginx.vim

%files core
%license LICENSE
%{_sbindir}/nginx
%config(noreplace) %{_sysconfdir}/nginx/koi-utf
%config(noreplace) %{_sysconfdir}/nginx/koi-win
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf.default
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params.default
%if ! 0%{with mailcap_mimetypes}
%config(noreplace) %{_sysconfdir}/nginx/mime.types
%endif
%config(noreplace) %{_sysconfdir}/nginx/win-utf
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf
%config(noreplace) %{_sysconfdir}/nginx/scgi_params
%config(noreplace) %{_sysconfdir}/logrotate.d/nginx
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params
%attr(711,root,root) %dir %{_localstatedir}/log/nginx
%config(noreplace) %{_sysconfdir}/nginx/mime.types.default
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf.default
%config(noreplace) %{_sysconfdir}/nginx/scgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params.default
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx/tmp
%ghost %attr(640,%{nginx_user},root) %{_localstatedir}/log/nginx/error.log
%ghost %attr(640,%{nginx_user},root) %{_localstatedir}/log/nginx/access.log
%dir %{nginx_moduledir}
%dir %{nginx_moduleconfdir}

%files all-modules

%files filesystem
%dir %{_datadir}/nginx
%dir %{_sysconfdir}/nginx
%dir %{_datadir}/nginx/html
%dir %{_sysconfdir}/nginx/conf.d
%dir %{_unitdir}/nginx.service.d
%dir %{_sysconfdir}/nginx/default.d
%dir %{_sysconfdir}/systemd/system/nginx.service.d

%if %{with geoip}
%files mod-http-geoip
%{nginx_moduleconfdir}/mod-http-geoip.conf
%{nginx_moduledir}/ngx_http_geoip_module.so
%endif

%files mod-http-image-filter
%{nginx_moduleconfdir}/mod-http-image-filter.conf
%{nginx_moduledir}/ngx_http_image_filter_module.so
%{abidir}/ngx_http_image_filter_module.dump

%files mod-http-perl
%{perl_vendorarch}/nginx.pm
%dir %{perl_vendorarch}/auto/nginx
%{perl_vendorarch}/auto/nginx/nginx.so
%{nginx_moduleconfdir}/mod-http-perl.conf
%{nginx_moduledir}/ngx_http_perl_module.so
%{abidir}/ngx_http_perl_module.dump

%files mod-http-xslt-filter
%{nginx_moduleconfdir}/mod-http-xslt-filter.conf
%{nginx_moduledir}/ngx_http_xslt_filter_module.so
%{abidir}/ngx_http_xslt_filter_module.dump

%files mod-mail
%{nginx_moduleconfdir}/mod-mail.conf
%{nginx_moduledir}/ngx_mail_module.so
%{abidir}/ngx_mail_module.dump

%files mod-stream
%{nginx_moduleconfdir}/mod-stream.conf
%{nginx_moduledir}/ngx_stream_module.so
%{abidir}/ngx_stream_module.dump

%files mod-devel
%{nginx_srcdir}/
%{_fileattrsdir}/nginxmods.attr
%{_rpmmacrodir}/macros.nginxmods

%files doc
%doc CHANGES README README.dynamic

%changelog
* Wed Mar 19 2025 Hong Wei Qin <qhw01063182@alibaba-inc.com> - 1:1.26.2-1
- Update to 1.26.2 from 1.24.0

* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> 1:1.24.0-2
- Update some description and add abi file

* Wed Apr 12 2023 Funda Wang <fundawang@yeah.net> - 1:1.24.0-1
- New version 1.24.0

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.23.3-2
- Del Specific Fields

* Mon Feb 6 2023 Funda Wang <fundawang@yeah.net> - 1:1.23.3-1
- New version 1.23.3

* Sun Oct 30 2022 Funda Wang <fundawang@yeah.net> - 1:1.23.2-1
- New version 1.23.2

* Wed Aug 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:1.23.1-2
- fix nginx-doc requires

* Mon Aug 15 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.23.1-1
- Update to 1.23.1
- Replace pcre to pcre2

* Fri Jul 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.21.6-2
- Fix the loss of nginx default HTML

* Tue May 17 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.21.6-1
- Init from upstream version 1.21.6
